==> fmagus-1.0.0.tar.gz: lib/src/functions/hive_configs_function.dart <==
import 'dart:io';

/// Function to create Route Generator
void hiveConfigs() {
  print(_start);

  _createHiveConfigs();

  print(_end);
}

//? PRIVATE
//+ GETTERS
String get _start => '''



╔════════════════════════════════════════════════════════════════════════════╗
║                                🧙 FMAGUS 🧙                                ║
╠════════════════════════════════════════════════════════════════════════════╣
║                        Starting Creating HiveConfigs...                    ║
╚════════════════════════════════════════════════════════════════════════════╝
''';

String get _end => '''



╔════════════════════════════════════════════════════════════════════════════╗
║                                🧙 FMAGUS 🧙                                ║
╠════════════════════════════════════════════════════════════════════════════╣
║                HiveConfigs Creating completed successfully!                ║
╚════════════════════════════════════════════════════════════════════════════╝
''';

String get _hiveConfigs => '''
import 'package:hive_flutter/hive_flutter.dart';

class HiveConfigs {
  //! ---------------------------------------->> CONSTANTS <<---------------------------------------- //

  //+ SETTINGS BOX
  static const String settingsBoxName = 'settings';
  static const String settingsAppThemeKey = 'appTheme';

  //! ---------------------------------------->> METHODS <<---------------------------------------- //

  //+ INIT
  static Future<void> initHive() async {
    await Hive.initFlutter();
  }
}
''';

//+ FUNCTIONS
void _createHiveConfigs() {
  print('\n\nCreating HiveConfigs...\n');
  File('lib/hive_configs.dart').writeAsStringSync(
    _hiveConfigs,
    mode: FileMode.writeOnly,
  );
  print('Creating Completed.');
}

==> fmagus-1.1.2.tar.gz: lib/src/functions/hive_configs_function.dart <==
import 'dart:io';

/// Function to create Route Generator
void hiveConfigs() {
  print(_start);

  _createHiveConfigs();

  print(_end);
}

//? PRIVATE
//+ GETTERS
String get _start => '''



╔════════════════════════════════════════════════════════════════════════════╗
║                                🧙 FMAGUS 🧙                                ║
╠════════════════════════════════════════════════════════════════════════════╣
║                        Starting Creating HiveConfigs...                    ║
╚════════════════════════════════════════════════════════════════════════════╝
''';

String get _end => '''



╔════════════════════════════════════════════════════════════════════════════╗
║                                🧙 FMAGUS 🧙                                ║
╠════════════════════════════════════════════════════════════════════════════╣
║                HiveConfigs Creating completed successfully!                ║
╚════════════════════════════════════════════════════════════════════════════╝
''';

String get _hiveConfigs => '''
import 'package:hive_flutter/hive_flutter.dart';

class HiveConfigs {
  //! ---------------------------------------->> CONSTANTS <<---------------------------------------- //

  //+ SETTINGS BOX
  static const String settingsBoxName = 'settings';
  static const String settingsAppThemeKey = 'appTheme';

  //! ---------------------------------------->> METHODS <<---------------------------------------- //

  //+ INIT
  static Future<void> initHive() async {
    await Hive.initFlutter();
  }
}
''';

//+ FUNCTIONS
void _createHiveConfigs() {
  print('\n\nCreating HiveConfigs...\n');
  Directory('lib/src/configs').createSync(recursive: true);
  File('lib/src/configs/hive_configs.dart').writeAsStringSync(
    _hiveConfigs,
    mode: FileMode.writeOnly,
  );
  print('Creating Completed.');
}
